@@ -14,7 +14,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(*i $Id: output.ml,v 1.57 2001/12/06 12:17:01 marche Exp $ i*)
+(*i $Id: output.ml,v 1.61 2003/01/31 16:51:46 filliatr Exp $ i*)
 
 (*i*)
 open Printf
@@ -95,7 +95,7 @@ let latex_header opt =
     output_string "\\usepackage";
     if opt <> "" then output_string (sprintf "[%s]" opt);
     output_string "{ocamlweb}\n";
-    output_string "\pagestyle{ocamlweb}\n";
+    output_string "\\pagestyle{ocamlweb}\n";
     Queue.iter (fun s -> output_string s; output_string "\n") preamble;
     output_string "\\begin{document}\n"
   end;
@@ -142,7 +142,7 @@ let leave_math () =
 
 let indentation n =
   let space = 0.5 *. (float n) in
-  output_string (sprintf "\ocwindent{%2.2fem}\n" space)
+  output_string (sprintf "\\ocwindent{%2.2fem}\n" space)
 
 
 (*s \textbf{End of lines.}
@@ -329,14 +329,14 @@ let output_yacc_ident s =
 
 let output_symbol = function
   | "*"  -> enter_math (); output_string "\\times{}"
-  | "**" -> enter_math (); output_string "*\!*"
+  | "**" -> enter_math (); output_string "*\\!*"
   | "->" -> enter_math (); output_string "\\rightarrow{}"
   | "<-" -> enter_math (); output_string "\\leftarrow{}"
   | "<=" -> enter_math (); output_string "\\le{}"
   | ">=" -> enter_math (); output_string "\\ge{}"
   | "<>" -> enter_math (); output_string "\\not="
   | "==" -> enter_math (); output_string "\\equiv"
-  | "!=" -> enter_math (); output_string "\\not\equiv"
+  | "!=" -> enter_math (); output_string "\\not\\equiv"
   | "~-" -> enter_math (); output_string "-"
   | "[<" -> enter_math (); output_string "[\\langle{}"
   | ">]" -> enter_math (); output_string "\\rangle{}]"
@@ -441,7 +441,7 @@ let reset_output () =
 (*s \textbf{Sectioning commands.} *)
 
 let begin_section () =
-  output_string "\\ocwsection\n"
+  output_string "\\allowbreak\\ocwsection\n"
 
 let output_typeout_command filename =
   output_string "\\typeout{OcamlWeb file ";
@@ -480,13 +480,21 @@ let output_yaccmodule module_name =
     output_string "}\n"
   end
       
-let last_is_code = ref false
+let in_code = ref false
 
 let begin_code () =
-  output_string "\\ocwbegincode{}"
-
+  if not !in_code then output_string "\\ocwbegincode{}";
+  in_code := true
 let end_code () =
-  output_string "\\ocwendcode{}"
+  if !in_code then output_string "\\ocwendcode{}";
+  in_code := false
+
+let begin_dcode () =
+  output_string "\\ocwbegindcode{}"
+let end_dcode () =
+  output_string "\\ocwenddcode{}"
+
+let last_is_code = ref false
 
 let begin_code_paragraph () =
   if not !last_is_code then output_string "\\medskip\n";
@@ -495,8 +503,8 @@ let begin_code_paragraph () =
 let end_code_paragraph is_last_paragraph =
   if is_last_paragraph then end_line() else output_string "\\medskip\n\n"
 
-let begin_doc_paragraph is_first_paragraph =
-  if not is_first_paragraph then output_string "\\noindent{}";
+let begin_doc_paragraph is_first_paragraph n =
+  if not is_first_paragraph then indentation n;
   last_is_code := false
 
 let end_doc_paragraph () =
